@@ -1,3 +1,5 @@
+// SPDX-License-Identifier: Apache-2.0
+// 
 // Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
 // Copyright 2008-2016 National ICT Australia (NICTA)
 // 
@@ -28,29 +30,13 @@ operator-
   const BaseCube<typename T1::elem_type,T1>& X
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return eOpCube<T1, eop_neg>(X.get_ref());
   }
 
 
 
-//! cancellation of two consecutive negations: -(-T1)
-template<typename T1>
-arma_inline
-const typename ProxyCube<T1>::stored_type&
-operator-
-  (
-  const eOpCube<T1, eop_neg>& X
-  )
-  {
-  arma_extra_debug_sigprint();
-  
-  return X.P.Q;
-  }
-
-
-
 //! BaseCube - scalar
 template<typename T1>
 arma_inline
@@ -61,7 +47,7 @@ operator-
   const typename T1::elem_type               k
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return eOpCube<T1, eop_scalar_minus_post>(X.get_ref(), k);
   }
@@ -78,7 +64,7 @@ operator-
   const BaseCube<typename T1::elem_type,T1>& X
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return eOpCube<T1, eop_scalar_minus_pre>(X.get_ref(), k);
   }
@@ -95,7 +81,7 @@ operator-
   const BaseCube<typename T1::pod_type, T1>& X
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return mtOpCube<typename std::complex<typename T1::pod_type>, T1, op_cx_scalar_minus_pre>('j', X.get_ref(), k);
   }
@@ -112,7 +98,7 @@ operator-
   const std::complex<typename T1::pod_type>& k
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return mtOpCube<typename std::complex<typename T1::pod_type>, T1, op_cx_scalar_minus_post>('j', X.get_ref(), k);
   }
@@ -129,7 +115,7 @@ operator-
   const BaseCube<typename T1::elem_type,T2>& Y
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return eGlueCube<T1, T2, eglue_minus>(X.get_ref(), Y.get_ref());
   }
@@ -146,7 +132,7 @@ operator-
   const BaseCube< typename force_different_type<typename T1::elem_type, typename T2::elem_type>::T2_result, T2>& Y
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename T1::elem_type eT1;
   typedef typename T2::elem_type eT2;
@@ -169,7 +155,7 @@ operator-
   const Base<eT,T2>&            Y
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return subview_cube_each1_aux::operator_minus(X, Y.get_ref());
   }
@@ -185,7 +171,7 @@ operator-
   const subview_cube_each1<eT>& Y
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return subview_cube_each1_aux::operator_minus(X.get_ref(), Y);
   }
@@ -201,7 +187,7 @@ operator-
   const Base<eT,T2>&               Y
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return subview_cube_each2_aux::operator_minus(X, Y.get_ref());
   }
@@ -217,7 +203,7 @@ operator-
   const subview_cube_each2<eT,TB>& Y
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return subview_cube_each2_aux::operator_minus(X.get_ref(), Y);
   }
